==> github-widget2-1.0.0.tgz: package/lib/test/logout.test.js <==
'use strict';

var _jsxFileName = '../../src/test/logout.test.jsx';

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _enzymeToJson = require('enzyme-to-json');

var _enzymeToJson2 = _interopRequireDefault(_enzymeToJson);

var _enzyme = require('enzyme');

var _Logout = require('../components/Logout/Logout');

var _renderActions = require('../actions/renderActions');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var logoutComponent = (0, _enzyme.shallow)(_react2.default.createElement(_Logout.Logout, {
  logout: _renderActions.logout,
  __source: {
    fileName: _jsxFileName,
    lineNumber: 9
  },
  __self: undefined
}));

describe('Logout Component', function () {
  it('renders a button component as specified', function () {
    expect((0, _enzymeToJson2.default)(logoutComponent)).toMatchSnapshot();
  });
  it('should have a length of 1', function () {
    expect(logoutComponent.toHave);
  });
  it('should contain an icon', function () {
    expect(logoutComponent.find('.icon').exists()).toBe(true);
  });
  it('should contain an icon, the icon should be a hand', function () {
    expect(logoutComponent.find('.hand').exists()).toBe(true);
  });
  // it('returns State To initialState ', () => {
  //   const logout = jest.fn();
  //   const expected = {
  //     avatarUrl: 'https://avatars1.githubusercontent.com/u/29614654?v=4',
  //     orgName: 'ShareCastG52',
  //   };
  //
  //   expect(mapStateToProps(state, { orgId: 238923429, widgetId: 'github' })).toEqual(expected);
  // });
  it('maps logout dispatches to props', function () {
    var dispatch = jest.fn();
    expect((0, _Logout.mapDispatchToProps)(dispatch)).toHaveProperty('logout');
  });
});

==> github-widget2-1.0.4.tgz: package/lib/test/logout.test.js <==
'use strict';

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _enzymeToJson = require('enzyme-to-json');

var _enzymeToJson2 = _interopRequireDefault(_enzymeToJson);

var _enzyme = require('enzyme');

var _Logout = require('../components/Logout/Logout');

var _renderActions = require('../actions/renderActions');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var logoutComponent = (0, _enzyme.shallow)(_react2.default.createElement(_Logout.Logout, {
  logout: _renderActions.logout
}));

describe('Logout Component', function () {
  it('renders a button component as specified', function () {
    expect((0, _enzymeToJson2.default)(logoutComponent)).toMatchSnapshot();
  });
  it('should have a length of 1', function () {
    expect(logoutComponent.toHave);
  });
  it('should contain an icon', function () {
    expect(logoutComponent.find('.icon').exists()).toBe(true);
  });
  it('should contain an icon, the icon should be a hand', function () {
    expect(logoutComponent.find('.hand').exists()).toBe(true);
  });
  // it('returns State To initialState ', () => {
  //   const logout = jest.fn();
  //   const expected = {
  //     avatarUrl: 'https://avatars1.githubusercontent.com/u/29614654?v=4',
  //     orgName: 'ShareCastG52',
  //   };
  //
  //   expect(mapStateToProps(state, { orgId: 238923429, widgetId: 'github' })).toEqual(expected);
  // });
  it('maps logout dispatches to props', function () {
    var dispatch = jest.fn();
    expect((0, _Logout.mapDispatchToProps)(dispatch)).toHaveProperty('logout');
  });
});
